@@ -1,5 +1,5 @@
 ## File Name: IRT.likelihood.immer_hrm.R
-## File Version: 0.08
+## File Version: 0.092
 
 
 
@@ -8,9 +8,9 @@
 IRT.likelihood.immer_hrm <- function( object, ... )
 {
     ll <- object$f.yi.qk
-    attr(ll,"theta") <- object$theta_like
-    attr(ll,"prob.theta") <- object$pi.k
-    attr(ll,"G") <- 1
+    attr(ll,'theta') <- object$theta_like
+    attr(ll,'prob.theta') <- object$pi.k
+    attr(ll,'G') <- 1
     return(ll)
 }
 #############################################################
@@ -21,9 +21,9 @@ IRT.likelihood.immer_hrm <- function( object, ... )
 IRT.posterior.immer_hrm <- function( object, ... )
 {
     ll <- object$f.qk.yi
-    attr(ll,"theta") <- object$theta_like
-    attr(ll,"prob.theta") <- object$pi.k
-    attr(ll,"G") <- 1
+    attr(ll,'theta') <- object$theta_like
+    attr(ll,'prob.theta') <- object$pi.k
+    attr(ll,'G') <- 1
     return(ll)
 }
 #############################################################
