@@ -1,5 +1,5 @@
 ## File Name: immer_IRT_likelihood_gpcm_helper.R
-## File Version: 0.06
+## File Version: 0.073
 
 immer_IRT_likelihood_gpcm_helper <- function(theta, b, a, dat, dat_resp=NULL)
 {
@@ -15,10 +15,11 @@ immer_IRT_likelihood_gpcm_helper <- function(theta, b, a, dat, dat_resp=NULL)
     #-- compute probabilities
     probs <- immer_gpcm_calc_probs( theta=theta, b=b, a=a )
     #-- compute individual likelihood
-    like <- immer_irt_likelihood_gpcm( probs=probs, dat=dat, dat_resp=dat_resp, TP=TP, K=K )
-    attr(like, "theta") <- theta
-    attr(like, "prob.theta") <- NA
-    attr(like, "skillspace") <- NA
-    attr(like, "G") <- NA
+    like <- immer_irt_likelihood_gpcm( probs=probs, dat=dat, dat_resp=dat_resp,
+                            TP=TP, K=K )
+    attr(like, 'theta') <- theta
+    attr(like, 'prob.theta') <- NA
+    attr(like, 'skillspace') <- NA
+    attr(like, 'G') <- NA
     return(like)
 }
