@@ -1,5 +1,5 @@
 ## File Name: immer_cmml_prepare.R
-## File Version: 0.32
+## File Version: 0.332
 
 immer_cmml_prepare <- function( dat, Q=NULL, weights=NULL)
 {
@@ -21,13 +21,13 @@ immer_cmml_prepare <- function( dat, Q=NULL, weights=NULL)
 
     #-- count frequencies
     dfr <- immer_cmml_proc_freq(dat=dat, dat_resp=dat_resp, K=K, weights=weights)
-    colnames(dfr) <- c("item1","item2","cat1","cat2","freq","ll_index")
+    colnames(dfr) <- c('item1','item2','cat1','cat2','freq','ll_index')
     dfr <- as.data.frame(dfr)
     sz <- rowsum( dfr$freq, dfr$ll_index )
     dfr$ntot <- sz[dfr$ll_index]
-    item_table <- dfr[, 1:4]
+    item_table <- dfr[, 1L:4]
     item_pairs <- item_table[ ( item_table$cat1==0 ) & ( item_table$cat2==0 ), ]
-    item_pairs <- item_pairs[, c("item1", "item2") ]
+    item_pairs <- item_pairs[, c('item1', 'item2') ]
 
     #----------------------------
     #-- design matrices
@@ -46,7 +46,7 @@ immer_cmml_prepare <- function( dat, Q=NULL, weights=NULL)
 
     #*** tau
     res <- immer_cmml_proc_generate_tau(maxK=maxK, K=K)
-    thresh <- paste0("thresh",0:(K+1))
+    thresh <- paste0('thresh',0:(K+1))
     tau <- immer_matrix_add_names(x=res$tau, row=items, col=thresh)
     tau_index <- immer_matrix_add_names(x=res$tau_index, row=items, col=thresh)
     #***
@@ -59,7 +59,7 @@ immer_cmml_prepare <- function( dat, Q=NULL, weights=NULL)
     #*** LAM
     if ( is.null(Q) ){
         Q <- matrix( 1, nrow=I, ncol=1)
-        colnames(Q) <- "F"
+        colnames(Q) <- 'F'
     }
     Q <- immer_matrix_add_names(x=Q, row=items)
     Q_col <- colnames(Q)
@@ -71,7 +71,7 @@ immer_cmml_prepare <- function( dat, Q=NULL, weights=NULL)
     LAM_init <- 0*LAM
     W_LAM <- res$W_LAM
     LAM_basispar <- res$LAM_basispar
-    LAM_basispar <- immer_vector_add_names(LAM_basispar, "LAM_b")
+    LAM_basispar <- immer_vector_add_names(LAM_basispar, 'LAM_b')
     cpml_design$LAM <- LAM
     cpml_design$LAM_index <- LAM_index
     cpml_design$LAM_init <- LAM_init
@@ -86,7 +86,7 @@ immer_cmml_prepare <- function( dat, Q=NULL, weights=NULL)
     N_GAM <- max(GAM_index)
     W_GAM <- diag(N_GAM)
     GAM_basispar <- GAM[ GAM_index > 0 ]
-    GAM_basispar <- immer_vector_add_names(GAM_basispar, "GAM_b")
+    GAM_basispar <- immer_vector_add_names(GAM_basispar, 'GAM_b')
 
     cpml_design$GAM <- GAM
     cpml_design$GAM_index <- GAM_index
@@ -100,7 +100,7 @@ immer_cmml_prepare <- function( dat, Q=NULL, weights=NULL)
     PHI_index <- immer_matrix_add_names(x=res$PHI_index, row=Q_col, col=Q_col)
     PHI_init <- immer_matrix_add_names(x=res$PHI_init, row=Q_col, col=Q_col)
     W_PHI <- res$W_PHI
-    PHI_basispar <- immer_vector_add_names(res$PHI_basispar, "PHI_b")
+    PHI_basispar <- immer_vector_add_names(res$PHI_basispar, 'PHI_b')
 
     cpml_design$PHI <- PHI
     cpml_design$PHI_index <- PHI_index
@@ -114,7 +114,7 @@ immer_cmml_prepare <- function( dat, Q=NULL, weights=NULL)
     PSI_index <- immer_matrix_add_names(x=res$PHI_index, row=items, col=items)
     PSI_init <- immer_matrix_add_names(x=res$PHI_init, row=items, col=items)
     W_PSI <- res$W_PHI
-    PSI_basispar <- immer_vector_add_names(res$PHI_basispar, "PSI_b")
+    PSI_basispar <- immer_vector_add_names(res$PHI_basispar, 'PSI_b')
 
     cpml_design$PSI <- PSI
     cpml_design$PSI_index <- PSI_index
@@ -122,7 +122,7 @@ immer_cmml_prepare <- function( dat, Q=NULL, weights=NULL)
     cpml_design$W_PSI <- W_PSI
     cpml_design$PSI_basispar <- PSI_basispar
 
-    attr(dfr, "N") <- N
+    attr(dfr, 'N') <- N
 
     #--- output
     res <- list( dat=dat, dat_resp=dat_resp, maxK=maxK, K=K, weights=weights,
