@@ -1,20 +1,20 @@
 ## File Name: immer_create_design_matrix_A.R
-## File Version: 0.18
+## File Version: 0.192
 
 immer_create_design_matrix_A <- function( maxK, A, b_fixed, irtmodel, NA_val=99)
 {
     I <- length(maxK)
     K <- max(maxK)
     if ( ! is.null(A) ){
-        irtmodel <- "user"
+        irtmodel <- 'user'
     }
 
     #--- create design matrix A
     if ( is.null(A) ){
-        if (irtmodel=="PCM"){
+        if (irtmodel=='PCM'){
             A <- immer_create_design_matrix_A_PCM(maxK=maxK, I=I, K=K)
         }
-        if (irtmodel=="PCM2"){
+        if (irtmodel=='PCM2'){
             A <- immer_create_design_matrix_A_PCM2(maxK=maxK, I=I, K=K)
         }
 
@@ -22,16 +22,16 @@ immer_create_design_matrix_A <- function( maxK, A, b_fixed, irtmodel, NA_val=99)
 
     if ( is.null( dimnames(A) ) ){
         dimnames(A)[[1]] <- names(maxK)
-        dimnames(A)[[2]] <- paste0("Cat", 1:K)
-        dimnames(A)[[3]] <- paste0("parm", seq(1,(dim(A))[3]) )
+        dimnames(A)[[2]] <- paste0('Cat', 1L:K)
+        dimnames(A)[[3]] <- paste0('parm', seq(1,(dim(A))[3]) )
     }
 
     #--- fixed b values
-    if (is.null(b_fixed) & (irtmodel!="user")){
+    if (is.null(b_fixed) & (irtmodel!='user')){
         b_fixed <- matrix( 0, nrow=I, ncol=K)
         rownames(b_fixed) <- dimnames(A)[[1]]
         colnames(b_fixed) <- dimnames(A)[[2]]
-        for (ii in 1:I){
+        for (ii in 1L:I){
             if ( maxK[ii] < K){
                 b_fixed[ii, seq(maxK[ii]+1,K) ] <- NA_val
             }
