@@ -1,16 +1,16 @@
 ## File Name: immer_ic_hrm.R
-## File Version: 0.09
+## File Version: 0.102
 
-#######################################################
-# information criteria
+
+#-- information criteria
 immer_ic_hrm <- function( ic, summary.mcmcobj )
 {
     ic$n <- ic$N
     pars <- paste(summary.mcmcobj$parameter)
-    vars <- c("mu", "sigma", "a", "b",  "phi", "psi")
+    vars <- c('mu', 'sigma', 'a', 'b',  'phi', 'psi')
     VV <- length(vars)
     Npars <- NULL
-    for (vv in 1:VV){
+    for (vv in 1L:VV){
         ind <- which( substring( pars, 1, nchar( vars[vv] ) )==vars[vv] )
         Npars[ vars[vv] ] <- length(ind)
     }
@@ -19,4 +19,3 @@ immer_ic_hrm <- function( ic, summary.mcmcobj )
     ic <- immer_IC_calc(ic)
     return(ic)
 }
-############################################################
