@@ -1,7 +1,7 @@
 ## File Name: immer_identifiers_relabel.R
-## File Version: 0.18
+## File Version: 0.194
+
 
-####################################################################
 immer_identifiers_relabel <- function( dat, pid, rater )
 {
     pid <- paste( pid )
@@ -14,18 +14,15 @@ immer_identifiers_relabel <- function( dat, pid, rater )
     dat0$rater <- match( rater, rater_unique )
 
     # item parameters
-    item0 <- data.frame( "item"=colnames(dat),
-                        "N_Rat"=colSums( 1 - is.na( dat ) ),
-                        "M"=colMeans( dat, na.rm=TRUE )
+    item0 <- data.frame( item=colnames(dat), N_Rat=colSums( 1 - is.na( dat ) ),
+                                M=colMeans( dat, na.rm=TRUE )
             )
     # item and rater combinations
     rater_pars0 <- NULL
     I <- ncol(dat)
     R <- length(rater_unique)
-    for (ii in 1:I){
-        dfr <- data.frame( "item"=colnames(dat)[ii],
-                    "rater"=rater_unique,
-                    "rid"=1:R )
+    for (ii in 1L:I){
+        dfr <- data.frame( item=colnames(dat)[ii], rater=rater_unique, rid=1L:R )
         N_Rat <- stats::aggregate( 1 - is.na(dat[, ii  ]), list(rater), sum )
         M <- stats::aggregate( dat[,ii], list(rater), mean, na.rm=TRUE )
         ind <- match( dfr$rater, M[,1] )
@@ -34,12 +31,8 @@ immer_identifiers_relabel <- function( dat, pid, rater )
         rater_pars0 <- rbind( rater_pars0, dfr )
     }
 
-    res <- list( pid=dat0$pid, rater=dat0$rater,
-                dat=dat0[, - c(1,2), drop=FALSE ],
-                pid_unique=pid_unique,
-                rater_unique=rater_unique, item0=item0,
-                rater_pars0=rater_pars0
-            )
+    res <- list( pid=dat0$pid, rater=dat0$rater, dat=dat0[, - c(1,2), drop=FALSE ],
+                pid_unique=pid_unique, rater_unique=rater_unique, item0=item0,
+                rater_pars0=rater_pars0 )
     return(res)
 }
-####################################################################
