@@ -1,12 +1,12 @@
 ## File Name: immer_jml_calc_item_intercepts.R
-## File Version: 0.06
+## File Version: 0.071
 
 immer_jml_calc_item_intercepts <- function(A, xsi, b_fixed=0)
 {
     K <- dim(A)[2]
     b <- matrix( 0, nrow=dim(A)[1], ncol=K )
     b <- b + b_fixed
-    for (kk in 1:K){
+    for (kk in 1L:K){
         b[,kk] <- b[,kk] + A[,kk,] %*% xsi
     }
     return(b)
