@@ -1,7 +1,7 @@
 ## File Name: probs_hrm_R.R
-## File Version: 0.17
+## File Version: 0.181
+
 
-######################################################################
 probs_hrm_R <- function( x, xi, phi, psi, K, x_ind=NULL )
 {
     N <- length(xi)
@@ -9,7 +9,7 @@ probs_hrm_R <- function( x, xi, phi, psi, K, x_ind=NULL )
     p1 <- exp( - ( KM - ( xi + phi ) )^2 / ( 2 * psi ) )
     probs <- p1 / rowSums(p1, na.rm=TRUE)
     if ( ! is.null(x) ){
-        ind <- cbind( 1:N, x+1 )
+        ind <- cbind( 1L:N, x+1 )
         probs <- probs[ind ]
     }
     if ( ! is.null( x_ind) ){
@@ -17,4 +17,4 @@ probs_hrm_R <- function( x, xi, phi, psi, K, x_ind=NULL )
     }
     return(probs)
 }
-####################################################
+
